import React, { ReactNode } from 'react';
import { PopoverProps } from '../Popover';
export type CheckboxVariant = 'default' | 'tableCheckbox' | 'tableHeader';
export interface CheckboxProps extends Omit<React.HTMLAttributes<HTMLInputElement>, 'onChange' | 'title'> {
    /** Checked or Unchecked  */
    isChecked: boolean;
    /** Checkbox variant */
    variant?: CheckboxVariant;
    /** Disables the checkbox */
    isDisabled?: boolean;
    /** Partial selection state */
    isPartial?: boolean;
    /** error state */
    isError?: boolean;
    /** custom className */
    className?: string;
    /** menu options for table header */
    menuOptions?: Array<{
        label: string;
        value?: string;
        isDisabled?: boolean;
        isActive?: boolean;
        onClick?: (e: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    }>;
    /** callback called on change and user can use event as second argument */
    onChange?: (newValue: boolean, e: React.FormEvent<HTMLInputElement>) => void;
    /** Children */
    children?: ReactNode;
    /** Display additional content on button hover in popover */
    title?: ReactNode;
    /** In case there is a title prop, these are the props of the tooltip component */
    titleProps?: PopoverProps;
}
export declare const Checkbox: ({ isChecked, className, onChange, isDisabled, children, isPartial, isError, variant, menuOptions, title, titleProps, ...rest }: CheckboxProps) => JSX.Element;
