import { __assign } from 'tslib';
import { jsx, jsxs } from 'react/jsx-runtime';
import { useMemo, useState, useEffect } from 'react';
import { Notification } from '../Notification/index.js';
import classNames from 'classnames';
import AnimateHeight from 'react-animate-height';
import styles from './NotificationPanel.module.scss.js';
import { Button } from '../Button/index.js';

var values = {
  error: 5,
  urgent: 4,
  warning: 3,
  info: 2,
  success: 1
};
var compare = function (type1, type2) {
  var val1 = values[type1] || 0;
  var val2 = values[type2] || 0;
  return val2 > val1 ? type2 : type1;
};
var GroupedNotifications = function (_a) {
  var notifications = _a.notifications,
    isPanelOpen = _a.isPanelOpen,
    setIsPanelOpen = _a.setIsPanelOpen,
    groupedNotificationClassName = _a.groupedNotificationClassName;
  var maxType = useCalculateGroupedNotificationType(notifications);
  return jsxs(AnimateHeight, __assign({
    duration: 400,
    easing: 'var(--cubic_bezier)',
    height: isPanelOpen ? 'auto' : 56,
    className: classNames(styles['grouped-container'], groupedNotificationClassName)
  }, {
    children: [!isPanelOpen && jsx(Notification, __assign({
      type: maxType,
      variant: 'primary',
      className: styles['inactive-grouped-container']
    }, {
      children: jsxs("div", {
        children: ["You have ", notifications.length, " new notifications.", jsx(Button, __assign({
          variant: 'text',
          onClick: function () {
            return setIsPanelOpen(true);
          },
          className: styles['show-more']
        }, {
          children: "See Details"
        }))]
      })
    })), isPanelOpen && jsx("div", __assign({
      className: styles['active-grouped-container']
    }, {
      children: notifications.map(function (notification, index) {
        return jsx(Notification, __assign({}, notification, {
          className: classNames(notification.className, styles['grouped-notification']),
          variant: 'secondary'
        }), index);
      })
    }))]
  }));
};
var useCalculateGroupedNotificationType = function (notifications) {
  return useMemo(function () {
    var maxType = 'success';
    notifications.forEach(function (_a) {
      var type = _a.type;
      maxType = compare(maxType, type);
    });
    return maxType;
  }, [notifications]);
};
var useIsGrouped = function (notificationsCount) {
  var _a = useState(false),
    isPanelOpen = _a[0],
    setIsPanelOpen = _a[1];
  var _b = useState(false),
    isGroupedNotification = _b[0],
    setIsGroupedNotification = _b[1];
  useEffect(function () {
    if (notificationsCount > 1) {
      setIsGroupedNotification(true);
    }
    if (notificationsCount === 0) {
      setIsGroupedNotification(false);
      setIsPanelOpen(false);
    }
  }, [notificationsCount]);
  return [isGroupedNotification, isPanelOpen, setIsPanelOpen];
};
/** Notification Panel is meant to show the Notifications in the bottom of the screen, it includes the logic for grouped notifications*/
var NotificationPanel = function (_a) {
  var _b;
  var notifications = _a.notifications,
    _c = _a.isFooter,
    isFooter = _c === void 0 ? false : _c,
    className = _a.className,
    _d = _a.groupedNotificationClassName,
    groupedNotificationClassName = _d === void 0 ? '' : _d;
  var _e = useIsGrouped(notifications.length),
    isGroupedNotification = _e[0],
    isPanelOpen = _e[1],
    setIsPanelOpen = _e[2];
  if (notifications.length === 0) {
    return null;
  }
  return jsx("div", __assign({
    className: classNames(styles.base, (_b = {}, _b[styles['with-footer']] = isFooter, _b), className)
  }, {
    children: !isGroupedNotification ? jsx(Notification, __assign({}, notifications[0])) : jsx(GroupedNotifications, {
      notifications: notifications,
      isPanelOpen: isPanelOpen,
      setIsPanelOpen: setIsPanelOpen,
      groupedNotificationClassName: groupedNotificationClassName
    })
  }));
};

export { NotificationPanel };
//# sourceMappingURL=index.js.map
