import { __rest, __assign, __awaiter, __generator } from 'tslib';
import { jsxs, jsx } from 'react/jsx-runtime';
import { useState, useRef, useEffect } from 'react';
import Select, { components } from 'react-select';
import { ReactComponent as ReactComponent$1 } from '@netapp/icons/ic_close.svg';
import { ReactComponent as ReactComponent$3 } from '@netapp/icons/ic_dropdown_arrow_down.svg';
import { ReactComponent } from '@netapp/icons/ic_search.svg';
import { ReactComponent as ReactComponent$2 } from '@netapp/icons/ic_add.svg';
import { TooltipInfo } from '../TooltipInfo/index.js';
import { FieldErrorWarning } from '../FieldErrorWarning/index.js';
import classNames from 'classnames';
import cssStyles from './Select.module.scss.js';
import { FlashingDotsLoader } from '../FlashingDotsLoader/index.js';
import useMultiSelect from './useMultiSelect.js';
import { Typography } from '../Typography/index.js';
import { Button } from '../Button/index.js';
import { ButtonBase } from '../ButtonBase/index.js';

var CustomSearch = function (_a) {
  var selectProps = _a.selectProps;
  var onMenuInputFocus = selectProps.onMenuInputFocus,
    _b = selectProps.extraProps,
    isOptionsAddingEnabled = _b.isOptionsAddingEnabled,
    textFilter = _b.textFilter,
    setTextFilter = _b.setTextFilter;
  return jsx("input", {
    className: cssStyles['search-text'],
    autoCorrect: "off",
    autoComplete: "off",
    spellCheck: "false",
    type: "text",
    value: textFilter,
    onChange: function (e) {
      return setTextFilter(e.currentTarget.value);
    },
    onMouseDown: function (e) {
      e.stopPropagation();
      e.target.focus();
    },
    onTouchEnd: function (e) {
      e.stopPropagation();
      e.target.focus();
    },
    onFocus: onMenuInputFocus,
    placeholder: isOptionsAddingEnabled ? 'Search or Add' : 'Search'
  });
};
var MenuList = function (props) {
  var _a;
  var _b = (_a = props.selectProps) === null || _a === void 0 ? void 0 : _a.extraProps,
    textFilter = _b.textFilter,
    setTextFilter = _b.setTextFilter,
    isOptionsAddingEnabled = _b.isOptionsAddingEnabled,
    isCreatingOption = _b.isCreatingOption,
    onCreateOption = _b.onCreateOption,
    isComboBox = _b.isComboBox;
  var _c = props.selectProps,
    onApplyClick = _c.onApplyClick,
    onCancelClick = _c.onCancelClick,
    isSearchable = _c.isSearchable;
  return jsxs("div", __assign({
    className: cssStyles['multiselect-menu']
  }, {
    children: [isSearchable && jsxs("div", __assign({
      className: cssStyles['search']
    }, {
      children: [jsx(ReactComponent, {
        className: cssStyles['search-icon']
      }), jsx(CustomSearch, {
        selectProps: props.selectProps
      }), textFilter && jsx(Button, __assign({
        variant: 'icon',
        className: cssStyles['clear-search-button'],
        onClick: function () {
          return setTextFilter('');
        }
      }, {
        children: jsx(ReactComponent$1, {})
      })), isOptionsAddingEnabled && (isCreatingOption ? jsx(FlashingDotsLoader, {}) : jsx(Button, __assign({
        variant: 'text',
        icon: ReactComponent$2,
        className: cssStyles['create-option-button'],
        onClick: function () {
          return __awaiter(void 0, void 0, void 0, function () {
            var newOption;
            return __generator(this, function (_a) {
              switch (_a.label) {
                case 0:
                  return [4 /*yield*/, onCreateOption(textFilter)];
                case 1:
                  newOption = _a.sent();
                  props.selectOption(newOption);
                  return [2 /*return*/];
              }
            });
          });
        },

        isDisabled: (textFilter === null || textFilter === void 0 ? void 0 : textFilter.length) === 0
      }, {
        children: "Add"
      })))]
    })), jsx(components.MenuList, __assign({}, props)), isComboBox && jsxs("div", __assign({
      className: cssStyles['actions']
    }, {
      children: [jsx(ButtonBase, __assign({
        className: cssStyles['apply'],
        onClick: onApplyClick
      }, {
        children: "Apply"
      })), jsx(ButtonBase, __assign({
        className: cssStyles['cancel'],
        onClick: onCancelClick
      }, {
        children: "Clear"
      }))]
    }))]
  }));
};
var DropdownIndicator = function (props) {
  if (props.selectProps.isLoading) {
    return null;
  }
  return jsx("div", __assign({
    className: cssStyles['dropdown-indicator']
  }, {
    children: jsx(ReactComponent$3, {})
  }));
};
var LoadingIndicator = function () {
  return jsx(FlashingDotsLoader, {
    className: cssStyles['select-loading']
  });
};
var ClearIndicator = function (props) {
  var _a = props.children,
    children = _a === void 0 ? jsx("div", __assign({
      className: cssStyles['clear-indicator']
    }, {
      children: jsx(ReactComponent$1, {})
    })) : _a,
    _b = props.innerProps,
    ref = _b.ref,
    restInnerProps = __rest(_b, ["ref"]);
  return jsx("div", __assign({}, restInnerProps, {
    ref: ref
  }, {
    children: children
  }));
};
var SingleValue = function (props) {
  return jsx(components.SingleValue, __assign({}, props, {
    children: props.data.label
  }));
};
var OptionWithSecondaryLabel = function (_a) {
  var label = _a.label,
    label2 = _a.label2;
  return jsxs("div", __assign({
    className: cssStyles['option-with-secondary']
  }, {
    children: [jsx("div", __assign({
      className: cssStyles['option-label']
    }, {
      children: label
    })), jsx("div", __assign({
      className: cssStyles['option-secondary-label']
    }, {
      children: label2
    }))]
  }));
};
var Option = function (props) {
  return jsx("div", __assign({
    className: cssStyles['custom-option'],
    title: props.data.isDisabled ? props.data.disabledTitle : props.data.label
  }, {
    children: jsx(components.Option, __assign({}, props))
  }));
};
var defaultStyles = {
  menu: function (base) {
    return __assign(__assign({}, base), {
      marginTop: 0
    });
  }
};
var SelectField = function (props) {
  var _a, _b;
  var _c, _d;
  var error = props.error,
    warning = props.warning,
    label = props.label,
    isLoading = props.isLoading,
    _e = props.isSearchable,
    isSearchable = _e === void 0 ? true : _e,
    className = props.className,
    info = props.info,
    styles = props.styles,
    isReadOnly = props.isReadOnly,
    options = props.options,
    onChange = props.onChange,
    _f = props.isCreatingOption,
    isCreatingOption = _f === void 0 ? false : _f,
    onCreateOption = props.onCreateOption,
    _g = props.isOptional,
    isOptional = _g === void 0 ? false : _g,
    placeholder = props.placeholder,
    value = props.value,
    _h = props.variant,
    variant = _h === void 0 ? 'default' : _h,
    _j = props.isDisabled,
    isDisabled = _j === void 0 ? false : _j,
    isBottomMarginRemoved = props.isBottomMarginRemoved,
    infoProps = props.infoProps,
    _k = props.isOptionsAddingEnabled,
    isOptionsAddingEnabled = _k === void 0 ? false : _k,
    components = props.components,
    rest = __rest(props, ["error", "warning", "label", "isLoading", "isSearchable", "className", "info", "styles", "isReadOnly", "options", "onChange", "isCreatingOption", "onCreateOption", "isOptional", "placeholder", "value", "variant", "isDisabled", "isBottomMarginRemoved", "infoProps", "isOptionsAddingEnabled", "components"]);
  var _l = useState(''),
    textFilter = _l[0],
    setTextFilter = _l[1];
  var _m = useState(false),
    isFocused = _m[0],
    setIsFocused = _m[1];
  var _o = useState(false),
    isMenuOpen = _o[0],
    setIsMenuOpen = _o[1];
  var extraClass = variant === 'underline' ? cssStyles.underline : variant === 'inline' ? cssStyles.inline : cssStyles.default;
  var removeLabel = variant === 'underline' || variant === 'inline';
  var containerRef = useRef(null);
  var _p = useMultiSelect(props, setIsMenuOpen, setTextFilter),
    multiSelectComponents = _p.components,
    multiSelectProps = __rest(_p, ["components"]);
  var isComboBox = (_c = props.multiSelectProps) === null || _c === void 0 ? void 0 : _c.isComboBox;
  useEffect(function () {
    var onDomClick = function (e) {
      var _a;
      if (!((_a = containerRef === null || containerRef === void 0 ? void 0 : containerRef.current) === null || _a === void 0 ? void 0 : _a.contains(e.target)) && !isComboBox) {
        setIsMenuOpen(false);
      }
    };
    document.addEventListener('mousedown', onDomClick);
    return function () {
      document.removeEventListener('mousedown', onDomClick);
    };
  }, [isComboBox]);
  var compProps = __assign(__assign({
    components: __assign(__assign({
      DropdownIndicator: DropdownIndicator,
      Option: Option,
      SingleValue: SingleValue,
      ClearIndicator: ClearIndicator,
      LoadingIndicator: LoadingIndicator,
      MenuList: MenuList
    }, multiSelectComponents), components),
    className: classNames(cssStyles['base-select'], extraClass, (_a = {}, _a[cssStyles.error] = error, _a)),
    classNames: {
      control: function () {
        return isReadOnly ? 'read-only' : '';
      }
    },
    classNamePrefix: 'design-system-select',
    formatOptionLabel: variant === 'two-lines' ? OptionWithSecondaryLabel : undefined,
    defaultMenuIsOpen: false,
    captureMenuScroll: false,
    maxMenuHeight: 150,
    isSearchable: isSearchable,
    placeholder: placeholder,
    options: options,
    value: value,
    isLoading: isLoading,
    isClearable: true,
    styles: __assign(__assign({}, defaultStyles), styles),
    isDisabled: isDisabled || isReadOnly || isLoading,
    onInputChange: function (val) {
      return setTextFilter(val);
    },
    isOptionDisabled: function (option) {
      return option.isDisabled;
    },
    extraProps: {
      textFilter: textFilter,
      setTextFilter: setTextFilter,
      isOptionsAddingEnabled: isOptionsAddingEnabled,
      isCreatingOption: isCreatingOption,
      onCreateOption: onCreateOption,
      isComboBox: (_d = props.multiSelectProps) === null || _d === void 0 ? void 0 : _d.isComboBox
    },
    menuIsOpen: isMenuOpen,
    isFocused: isFocused || undefined,
    onMenuInputFocus: function () {
      return setIsFocused(true);
    },
    onMenuOpen: function () {
      return setIsMenuOpen(function (prev) {
        return !prev;
      });
    },
    hideSelectedOptions: false,
    onChange: function (newValue, actionMeta) {
      setIsMenuOpen(false);
      if (onChange) {
        onChange(newValue);
      }
    }
  }, multiSelectProps), rest);
  return jsxs("div", __assign({
    ref: containerRef,
    className: classNames(cssStyles.base, className, (_b = {}, _b[cssStyles.disabled] = isDisabled, _b[cssStyles['bottom-margin']] = !isBottomMarginRemoved, _b))
  }, {
    children: [(label && !removeLabel || isOptional) && jsxs("div", __assign({
      className: cssStyles['select-top']
    }, {
      children: [label && jsx(Typography, __assign({
        Component: 'label',
        variant: 'Regular_14',
        className: cssStyles['label']
      }, {
        children: label
      })), isOptional && jsx(Typography, __assign({
        className: cssStyles['optional'],
        variant: 'Regular_14'
      }, {
        children: "Optional"
      })), info && jsx(TooltipInfo, __assign({}, infoProps, {
        children: info
      }))]
    })), jsx(Select, __assign({}, compProps)), jsx(FieldErrorWarning, {
      error: error,
      warning: warning
    })]
  }));
};

export { SelectField };
//# sourceMappingURL=index.js.map
