import { __assign } from 'tslib';
import { jsxs, jsx } from 'react/jsx-runtime';
import { useState } from 'react';
import styles from './TableTopBar.module.scss.js';
import { Typography } from '../Typography/index.js';
import classNames from 'classnames';
import { TooltipInfo } from '../TooltipInfo/index.js';
import { Button } from '../Button/index.js';
import { Parser } from '@json2csv/plainjs';
import { ReactComponent } from '@netapp/icons/ic_download.svg';
import _pick from 'lodash/pick';
import _mapKeys from 'lodash/mapKeys';
import _map from 'lodash/map';
import { SearchInput } from '../SearchInput/index.js';
import { FlashingDotsLoader } from '../FlashingDotsLoader/index.js';

var exportToCsv = function (_a, tableProps) {
  var fileName = _a.fileName,
    _b = _a.options,
    options = _b === void 0 ? {} : _b;
  var organizedRows = tableProps.organizedRows,
    columns = tableProps.columns;
  var selectedColumns = columns.map(function (column) {
    return column.accessor;
  }).filter(function (accessor) {
    return accessor;
  });
  var keysMapping = columns.reduce(function (acc, val) {
    if (typeof val.Header === 'string' && val.accessor) {
      acc[val.accessor] = val.Header;
    }
    return acc;
  }, {});
  var data = organizedRows.map(function (row) {
    return _pick(row, selectedColumns);
  });
  var dataWithTableHeaders = _map(data, function (rows) {
    return _mapKeys(rows, function (value, key) {
      return keysMapping[key] || key;
    });
  });
  var parser = new Parser(options);
  var parsedData = parser.parse(dataWithTableHeaders);
  var element = document.createElement('a');
  element.setAttribute('href', "data:text/plain;charset=utf-8,".concat(encodeURIComponent(parsedData)));
  element.setAttribute('download', fileName);
  element.style.display = 'none';
  document.body.appendChild(element);
  element.click();
  document.body.removeChild(element);
};
var TableTopBar = function (_a) {
  var _b;
  var tableProps = _a.tableProps,
    singularTitle = _a.singularTitle,
    pluralTitle = _a.pluralTitle,
    info = _a.info,
    className = _a.className,
    initialTextFilter = _a.initialTextFilter,
    actionsRight = _a.actionsRight,
    actionsLeft = _a.actionsLeft,
    exportToCsvOptions = _a.exportToCsvOptions,
    searchInputProps = _a.searchInputProps,
    _c = _a.lazyLoadingText,
    lazyLoadingText = _c === void 0 ? 'Loading' : _c;
  var organizedRows = tableProps.organizedRows,
    updateTextFilter = tableProps.updateTextFilter,
    rows = tableProps.rows,
    filterState = tableProps.filterState,
    resetFilters = tableProps.resetFilters,
    selectionState = tableProps.selectionState,
    isLazyLoading = tableProps.isLazyLoading;
  var _d = useState(initialTextFilter),
    inputTextFilter = _d[0],
    setInputTextFilter = _d[1];
  var itemCount = rows.length;
  var filteredItemCount = organizedRows.length;
  var textFilter = filterState === null || filterState === void 0 ? void 0 : filterState.textFilter;
  var showFilterText = (filterState === null || filterState === void 0 ? void 0 : filterState.count) > 0 || textFilter;
  var showSelectionText = selectionState && (selectionState === null || selectionState === void 0 ? void 0 : selectionState.count) > 0;
  return jsxs("div", __assign({
    className: classNames(styles.base, className)
  }, {
    children: [jsxs(Typography, __assign({
      variant: 'Semibold_16',
      isEllipsis: true,
      className: styles.title
    }, {
      children: [jsx("span", {
        children: itemCount === 1 ? singularTitle : pluralTitle
      }), jsxs("span", {
        children: ["(", itemCount === filteredItemCount ? itemCount : filteredItemCount + '/' + itemCount, ")"]
      }), info && jsx(TooltipInfo, __assign({
        isAppendedToBody: true
      }, {
        children: info
      })), showFilterText && jsx("span", {
        children: "| Filtered by".concat(textFilter ? ' search' : '').concat(textFilter && (filterState === null || filterState === void 0 ? void 0 : filterState.count) > 0 ? ' & ' : '').concat((filterState === null || filterState === void 0 ? void 0 : filterState.count) ? " ".concat(filterState === null || filterState === void 0 ? void 0 : filterState.count, " parameter").concat((filterState === null || filterState === void 0 ? void 0 : filterState.count) > 1 ? 's' : '') : '')
      }), showSelectionText && jsx("span", {
        children: "| ".concat((selectionState === null || selectionState === void 0 ? void 0 : selectionState.count) === itemCount ? 'All selected' : "".concat(selectionState === null || selectionState === void 0 ? void 0 : selectionState.count, " selected"))
      }), showFilterText && jsx(Button, __assign({
        variant: 'text',
        onClick: function () {
          resetFilters();
          setInputTextFilter('');
        }
      }, {
        children: "Reset filters"
      })), isLazyLoading && jsxs("div", __assign({
        className: styles['lazy-loading-indication']
      }, {
        children: [jsx(Typography, __assign({
          variant: 'Semibold_16'
        }, {
          children: "|"
        })), jsx(FlashingDotsLoader, {
          className: styles['lazy-loading']
        }), jsx(Typography, __assign({
          variant: 'Regular_14'
        }, {
          children: lazyLoadingText
        }))]
      }))]
    })), jsxs("div", __assign({
      className: styles.actions
    }, {
      children: [actionsLeft, jsx(SearchInput, __assign({
        value: inputTextFilter,
        isDisabled: isLazyLoading,
        onChange: function (value) {
          setInputTextFilter(value);
          updateTextFilter(value);
        }
      }, searchInputProps)), exportToCsvOptions && jsx(Button, __assign({
        className: styles.export,
        variant: 'icon',
        isDisabled: ((_b = tableProps === null || tableProps === void 0 ? void 0 : tableProps.organizedRows) === null || _b === void 0 ? void 0 : _b.length) === 0 || isLazyLoading,
        title: 'Export to CSV',
        onClick: function () {
          return exportToCsv(exportToCsvOptions, tableProps);
        }
      }, {
        children: jsx(ReactComponent, {})
      })), actionsRight]
    }))]
  }));
};

export { TableTopBar, exportToCsv };
//# sourceMappingURL=TableTopBar.js.map
