import React from 'react';
import { ColumnProps, SelectionStateType } from './index';
import { HashTable } from '../../utils/types';
export declare const getFilterOptions: (data: rowDataType[], column: ColumnProps) => {
    value: never;
    label: any;
}[];
export type RowsStateType = {
    isExpanded?: boolean;
};
export type rowDataType = {
    id: string;
    cellProps?: {
        /** Custom classname for every cell in the row */
        className?: string;
        /** Show skeleton instead of the row data */
        isLoading?: boolean;
        /** Is the row disabled? including selection */
        isDisabled?: boolean;
        /** In case of selection, props to add for the Checkbox or CheckButton */
        selectionProps?: any;
    };
};
export type SortOrderType = 'asc' | 'desc' | null;
export type SortStateType = {
    sortOrder?: SortOrderType;
    column?: string;
} | null;
export interface ColumnFilterStateType {
    values: HashTable<boolean>;
    valuesArray: boolean[];
    activeCount: number;
}
export type FilterStateType = {
    textFilter: string;
    columns: {
        [p: string]: ColumnFilterStateType;
    };
    count: number;
};
export interface ColumnStateType {
    activeCount?: number;
    isHidden?: boolean;
    isRemovalDisabled?: boolean;
}
export type SelectionType = 'none' | 'singular' | 'multiple';
export interface UseTableProps {
    /** Should the first column should be sorted by default */
    isSorting: boolean;
    /** Are the rows selectable? */
    selectionType?: SelectionType;
    /** Table columns */
    columns: ColumnProps[];
    /** Table Rows */
    rows: rowDataType[];
    /** Should the internal sorting mechanism be disabled */
    isExternalSort?: boolean;
    /** Should the internal filtering mechanism be disabled */
    isExternalFilter?: boolean;
    /** What should be the initial sorting state */
    initialSortState?: SortStateType;
    /** What should be the initial filter state */
    initialFilterState?: FilterStateType;
    /** What should be the initial column state */
    initialColumnState?: HashTable<ColumnStateType>;
    /** How many rows in every page */
    pageSize?: number;
    /** If selection type is not none, which rows ID should be selected by default */
    defaultSelectedRows?: string[];
    /** In case of text filter, these keys in the data will also be searched */
    additionalSearchKeys?: string[];
    /** Can the user add or remove columns? */
    isManagedColumns?: boolean;
    /** Is the table have horizontal scroll, if true, all the columns need fixed width properties */
    isHorizontalScroll?: boolean;
    /** The state if the column, used in case column is hidden (isManagedColumns prop) */
    columnsState?: HashTable<ColumnStateType>;
    /** If we didnt finish loading the rows it should be true */
    isLazyLoading?: boolean;
    /** In case of multiple selection, should select all be disabled? */
    isSelectAllDisabled?: boolean;
}
export declare const useTable: ({ isSorting, selectionType, columns, rows: data, isExternalSort, isExternalFilter, initialSortState, initialFilterState, initialColumnState, pageSize, defaultSelectedRows, additionalSearchKeys, isManagedColumns, isHorizontalScroll, isLazyLoading, isSelectAllDisabled, }: UseTableProps) => {
    rows: {
        id: string;
        cellProps?: {
            /** Custom classname for every cell in the row */
            className?: string | undefined;
            /** Show skeleton instead of the row data */
            isLoading?: boolean | undefined;
            /** Is the row disabled? including selection */
            isDisabled?: boolean | undefined;
            /** In case of selection, props to add for the Checkbox or CheckButton */
            selectionProps?: any;
        } | undefined;
    }[];
    organizedRows: rowDataType[];
    allColumns: ColumnProps[];
    columns: {
        className: string;
        id: string;
        Header: React.ReactNode | typeof React.Component;
        accessor: string;
        isSortable?: boolean | undefined;
        filterOptions?: "auto" | import("./index").filterOptionShape[] | undefined;
        info?: React.ReactNode;
        width?: string | undefined;
        renderCell?: ((cellData: any, rowData: rowDataType, rowMetaData: import("./index").RowMetaData) => React.ReactNode) | undefined;
        renderFilterPanelLabel?: Function | undefined;
        infoProps?: import("../TooltipInfo").TooltipInfoProps | undefined;
        isSticky?: boolean | undefined;
        accessorForTextFilter?: string | undefined;
        filterState?: ColumnFilterStateType | undefined;
        updateColumnFilter?: Function | undefined;
        toggleSort?: React.MouseEventHandler<HTMLButtonElement> | undefined;
        columnSortState?: SortOrderType | undefined;
    }[];
    sortState: SortStateType;
    filterState: FilterStateType;
    rowsState: HashTable<RowsStateType>;
    selectionState: SelectionStateType;
    toggleSort: ({ id }: {
        id: string;
    }) => void;
    updateFilterState: (payload: {
        id: string;
        values: HashTable<boolean>;
    }) => void;
    updateRowState: (id: string) => (state: any) => void;
    updateTextFilter: (value: string) => void;
    toggleRowSelection: (id: string) => (value: boolean) => void;
    selectRows: (rows: rowDataType[], value: boolean) => void;
    resetFilters: () => void;
    pagination: {
        pageIndex: number;
        pageRows: rowDataType[];
        pageCount: number;
        gotoPage: (i: number) => void;
    } | null;
    pageSize: number;
    updateColumnState: (state: any) => void;
    isHorizontalScroll: boolean;
    columnsState: HashTable<ColumnStateType>;
    isLazyLoading: boolean;
};
