import { usePopperTooltip } from 'react-popper-tooltip';
import {
  Config,
  PopperOptions,
  PropsGetterArgs,
} from 'react-popper-tooltip/dist/types';

type PredefinedProps = 'followCursor' | 'mutationObserverOptions' | 'offset';

export type PopoverConfig = Omit<Config, PredefinedProps> & {
  /**
   * Set top offset of a Popover
   * @default 0
   */
  offsetTop?: number;
  /**
   * Set left offset of a Popover
   * @default *
   */
  offsetLeft?: number;
  /**
   * Options for popper.js directly.
   */
  popperOptions?: PopperOptions;
};

const usePopover = (config?: PopoverConfig) => {
  const {
    placement = 'bottom',
    offsetTop = 0,
    offsetLeft = 8,
    popperOptions = {},
    ...configRest
  } = config || {};
  const { modifiers = [], ...popperOptionsRest } = popperOptions;

  const {
    getArrowProps, // Not in use since we don't have arrows inside UI
    getTooltipProps,
    setTooltipRef,
    tooltipRef,
    setTriggerRef,
    triggerRef,
    visible,
    ...rest
  } = usePopperTooltip(
    {
      ...configRest,
      placement,
    },
    {
      modifiers: [
        // Prevent popover flipping position
        // when it's too close to the edge of the screen
        {
          name: 'flip',
          enabled: false,
        },
        {
          name: 'offset',
          options: {
            offset: [offsetLeft, offsetTop],
          },
        },
        ...modifiers,
      ],
      ...popperOptionsRest,
    }
  );

  return {
    getPopoverProps: getTooltipProps,
    setPopoverRef: setTooltipRef,
    popoverRef: tooltipRef,
    isVisible: visible,
    setContainerRef: setTriggerRef,
    containerRef: triggerRef,
    ...rest,
  };
};

export default usePopover;
