import React from 'react';
export type ComponentProp<C extends React.ElementType> = {
    /** Render a component as specific html el or react component */
    Component?: C;
};
export type PropsToOmit<C extends React.ElementType, P> = keyof (ComponentProp<C> & P);
export type PolymorphicComponentProp<C extends React.ElementType, Props = {}> = React.PropsWithChildren<Props & ComponentProp<C>> & Omit<React.ComponentPropsWithoutRef<C>, PropsToOmit<C, Props>>;
export type PolymorphicComponentPropWithRef<C extends React.ElementType, Props = {}> = PolymorphicComponentProp<C, Props> & {
    /** Forwarded ref */
    ref?: PolymorphicRef<C>;
};
export type PolymorphicRef<C extends React.ElementType> = React.ComponentPropsWithRef<C>['ref'];
export interface FieldValueCallbackInfo {
    label: string;
    default?: string | undefined;
}
export type FieldValueCallback<T> = FieldValueCallbackWithoutField<T> | FieldValueCallbackWithField<T>;
export interface FieldValueCallbackWithoutField<T> {
    (row: T): any;
}
export interface FieldValueCallbackWithField<T> {
    (row: T, field: FieldValueCallbackInfo): any;
}
export type Json2CsvTransform<T1, T2> = (item: T1) => T2 | T2[];
export interface FieldInfo<T> {
    label?: string | undefined;
    default?: string | undefined;
    value: string | FieldValueCallback<T>;
}
export interface ExportToCsvOptions {
    fields?: Array<string | FieldInfo<Object>> | undefined;
    ndjson?: boolean | undefined;
    defaultValue?: string | undefined;
    quote?: string | undefined;
    escapedQuote?: string | undefined;
    delimiter?: string | undefined;
    eol?: string | undefined;
    excelStrings?: boolean | undefined;
    header?: boolean | undefined;
    includeEmptyRows?: boolean | undefined;
    withBOM?: boolean | undefined;
    transforms?: Array<Json2CsvTransform<any, any>> | undefined;
}
export interface HashTable<T> {
    [key: string]: T;
}
