import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import React__default from 'react';
import Select, { components } from 'react-select';
import CreatableSelect from 'react-select/creatable';
import SvgTriangle from '../../assets/svgs/triangle.svg.js';
import SvgCloseSmall from '../../assets/svgs/close-small.svg.js';
import PropTypes from 'prop-types';
import TooltipInfo from '../TooltipInfo/index.js';
import FieldExtra from '../FieldExtra/index.js';
import { SELECT_TYPES } from '../../consts.js';
import './select.scss.js';

var _excluded = ["ref"],
  _excluded2 = ["error", "warning", "label", "options", "isLoading", "isSearchable", "className", "info", "styles", "placeholder", "value", "variant", "disabled", "removeBottomMargin", "infoProps", "enableOptionsAdding", "components"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var DEFAULT = SELECT_TYPES.DEFAULT,
  UNDERLINE = SELECT_TYPES.UNDERLINE,
  INLINE = SELECT_TYPES.INLINE,
  TWO_LINES = SELECT_TYPES.TWO_LINES;
var DropdownIndicator = function DropdownIndicator() {
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-dropdown-indicator"
  }, /*#__PURE__*/React__default.createElement(SvgTriangle, null));
};
var ClearIndicator = function ClearIndicator(props) {
  var _props$children = props.children,
    children = _props$children === void 0 ? /*#__PURE__*/React__default.createElement("div", {
      className: "Suc-clear-indicator"
    }, /*#__PURE__*/React__default.createElement(SvgCloseSmall, null)) : _props$children,
    _props$innerProps = props.innerProps,
    ref = _props$innerProps.ref,
    restInnerProps = _objectWithoutProperties(_props$innerProps, _excluded);
  return /*#__PURE__*/React__default.createElement("div", _extends({}, restInnerProps, {
    ref: ref
  }), children);
};
var SingleValue = function SingleValue(props) {
  return /*#__PURE__*/React__default.createElement(components.SingleValue, props, props.data.label);
};
var OptionWithSecondaryLabel = function OptionWithSecondaryLabel(_ref) {
  var label = _ref.label,
    label2 = _ref.label2;
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-option-with-secondary"
  }, /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-option-label"
  }, label), /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-option-secondary-label"
  }, label2));
};
var Option = function Option(props) {
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-custom-option",
    title: props.data.disabled ? props.data.disabledTitle : props.data.label
  }, /*#__PURE__*/React__default.createElement(components.Option, _extends({}, props, {
    className: props.data.__isNew__ ? "Suc-create-option" : ""
  })));
};
var defaultStyles = {
  menu: function menu(base) {
    return _objectSpread(_objectSpread({}, base), {}, {
      marginTop: 0
    });
  }
};
var SelectField = function SelectField(props) {
  var error = props.error,
    warning = props.warning,
    label = props.label,
    options = props.options,
    isLoading = props.isLoading,
    isSearchable = props.isSearchable,
    className = props.className,
    info = props.info,
    styles = props.styles,
    placeholder = props.placeholder,
    value = props.value,
    variant = props.variant,
    disabled = props.disabled,
    removeBottomMargin = props.removeBottomMargin,
    infoProps = props.infoProps,
    enableOptionsAdding = props.enableOptionsAdding,
    components = props.components,
    rest = _objectWithoutProperties(props, _excluded2);
  var extraClass = "Suc-".concat(variant === UNDERLINE ? 'underline' : variant === INLINE ? 'inline' : 'default');
  var removeLabel = variant === UNDERLINE || variant === INLINE;
  var selectProps = _objectSpread({
    components: _objectSpread({
      DropdownIndicator: DropdownIndicator,
      Option: Option,
      SingleValue: SingleValue,
      ClearIndicator: ClearIndicator
    }, components),
    className: "Suc-Select ".concat(extraClass, " ").concat(error && 'Suc-error'),
    classNamePrefix: "Suc-Select",
    formatOptionLabel: variant === TWO_LINES ? OptionWithSecondaryLabel : undefined,
    defaultMenuIsOpen: false,
    onBlurResetsInput: false,
    onSelectResetsInput: false,
    captureMenuScroll: false,
    maxMenuHeight: 150,
    isSearchable: isSearchable,
    isClearable: false,
    placeholder: placeholder,
    options: options,
    value: value,
    isLoading: isLoading,
    styles: _objectSpread(_objectSpread({}, defaultStyles), styles),
    isDisabled: disabled,
    isOptionDisabled: function isOptionDisabled(option) {
      return option.disabled;
    }
  }, rest);
  return /*#__PURE__*/React__default.createElement("div", {
    className: "Suc-Select-container ".concat(className, " ").concat(disabled ? 'Suc-disabled' : '', " ").concat(removeBottomMargin ? '' : 'Suc-bottom-margin')
  }, label && !removeLabel && /*#__PURE__*/React__default.createElement("div", {
    className: 'Suc-select-top'
  }, label && /*#__PURE__*/React__default.createElement("label", null, label), info && /*#__PURE__*/React__default.createElement(TooltipInfo, infoProps, info)), !enableOptionsAdding && /*#__PURE__*/React__default.createElement(Select, selectProps), enableOptionsAdding && /*#__PURE__*/React__default.createElement(CreatableSelect, selectProps), /*#__PURE__*/React__default.createElement(FieldExtra, {
    error: error,
    warning: warning
  }));
};
var optionShape = PropTypes.shape({
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
  label: PropTypes.string,
  label2: PropTypes.string,
  //Used in "two-lines" variant
  disabled: PropTypes.bool,
  disabledTitle: PropTypes.string
});
SelectField.propTypes = {
  /** select's type */
  variant: PropTypes.oneOf([DEFAULT, UNDERLINE, INLINE, TWO_LINES]),
  /** disabled state */
  disabled: PropTypes.bool,
  /** custom classname */
  className: PropTypes.string,
  /** label */
  label: PropTypes.string,
  /** placeholder */
  placeholder: PropTypes.string,
  /** error text */
  error: PropTypes.string,
  /** warning text */
  warning: PropTypes.string,
  /** remove margin-bottom (to allow inline alignment) */
  removeBottomMargin: PropTypes.bool,
  /** options array */
  options: PropTypes.arrayOf(optionShape),
  /** selected option */
  value: PropTypes.oneOfType([optionShape, PropTypes.arrayOf(optionShape)]),
  /** show loader */
  isLoading: PropTypes.bool,
  /** allow search */
  isSearchable: PropTypes.bool,
  /** info tooltip */
  info: PropTypes.node,
  /** InfoTooltip props */
  infoProps: PropTypes.object,
  /** can add values that are not in the options */
  enableOptionsAdding: PropTypes.bool
};
SelectField.defaultProps = {
  className: '',
  variant: DEFAULT,
  error: '',
  warning: '',
  isSearchable: true,
  disabled: false,
  placeholder: ' - Select -',
  removeBottomMargin: false,
  infoProps: {},
  enableOptionsAdding: false,
  styles: {}
};

export { SelectField as default };
//# sourceMappingURL=index.js.map
