import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import _extends from '@babel/runtime/helpers/extends';
import React__default, { useEffect, useMemo } from 'react';
import useTable from '../Grid/useTable.js';
import Grid from '../Grid/index.js';
import './TreeTable.scss.js';
import PropTypes from 'prop-types';
import useRunOnceWhenTruthy from '../../hooks/useRunOnceWhenTruthy.js';
import ButtonBase from '../ButtonBase/index.js';
import SvgIcChevron from '../../assets/svgs/ic_chevron.svg.js';
import get from 'lodash/get';

var _excluded = ["expandByDefault", "childrenSearchKeys"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var ExpandedRow = function ExpandedRow(_ref) {
  var rowData = _ref.rowData,
    columns = _ref.columns,
    textFilter = _ref.textFilter;
  var tableProps = useTable({
    rows: rowData.children,
    columns: columns,
    isSorting: true,
    pageSize: 300
  });
  useEffect(function () {
    if (textFilter !== undefined) {
      tableProps.updateTextFilter(textFilter);
    }
  }, [textFilter]);
  return /*#__PURE__*/React__default.createElement(Grid, _extends({
    className: 'Suc-sub-grid'
  }, tableProps));
};
var useExpandByDefault = function useExpandByDefault(_ref2) {
  var _tableProps$rows;
  var tableProps = _ref2.tableProps,
    expandByDefault = _ref2.expandByDefault;
  useRunOnceWhenTruthy(function () {
    tableProps.rows.forEach(function (row) {
      if (row.children) {
        tableProps.updateRowState(row.id)({
          isExpanded: true
        });
      }
    });
  }, expandByDefault && ((_tableProps$rows = tableProps.rows) === null || _tableProps$rows === void 0 ? void 0 : _tableProps$rows.length) > 0);
};
var useChevronColumn = function useChevronColumn(columns) {
  return useMemo(function () {
    return [].concat(_toConsumableArray(columns), [{
      Header: '',
      accessor: 'childrenSearchValues',
      width: '60px',
      sticky: true,
      renderCell: function renderCell(value, rowData, _ref3) {
        var updateRowState = _ref3.updateRowState,
          rowState = _ref3.rowState;
        var currentRowState = rowState[rowData.id];
        return rowData.children ? /*#__PURE__*/React__default.createElement(ButtonBase, {
          style: {
            transform: "rotate(".concat(currentRowState !== null && currentRowState !== void 0 && currentRowState.isExpanded ? 0 : 180, "deg)")
          },
          onClick: function onClick() {
            updateRowState(rowData.id)({
              isExpanded: !(currentRowState !== null && currentRowState !== void 0 && currentRowState.isExpanded)
            });
          }
        }, /*#__PURE__*/React__default.createElement(SvgIcChevron, null)) : /*#__PURE__*/React__default.createElement("div", null);
      }
    }]);
  }, [columns]);
};
var getChildrenValues = function getChildrenValues(children, childrenSearchKeys) {
  return children === null || children === void 0 ? void 0 : children.reduce(function (acc, child) {
    childrenSearchKeys.forEach(function (childrenSearchKey) {
      var value = get(child, childrenSearchKey, null);
      if (value !== null) {
        acc.push(value);
      }
    });
    return acc;
  }, []);
};
var useDataWithChildrenSearchKeys = function useDataWithChildrenSearchKeys(rows, childrenSearchKeys) {
  return useMemo(function () {
    return rows.map(function (row) {
      if (!row.children) {
        return row;
      }
      return _objectSpread(_objectSpread({}, row), {}, {
        childrenSearchValues: getChildrenValues(row.children, childrenSearchKeys)
      });
    });
  }, [rows]);
};
var useTreeTable = function useTreeTable(_ref4) {
  var expandByDefault = _ref4.expandByDefault,
    childrenSearchKeys = _ref4.childrenSearchKeys,
    useTableProps = _objectWithoutProperties(_ref4, _excluded);
  var columnsWithChevron = useChevronColumn(useTableProps === null || useTableProps === void 0 ? void 0 : useTableProps.columns);
  var dataWithChildrenSearchKeys = useDataWithChildrenSearchKeys(useTableProps === null || useTableProps === void 0 ? void 0 : useTableProps.rows, childrenSearchKeys);
  var tableProps = useTable(_objectSpread(_objectSpread({}, useTableProps), {}, {
    columns: columnsWithChevron,
    rows: dataWithChildrenSearchKeys
  }));
  useExpandByDefault({
    tableProps: tableProps,
    expandByDefault: expandByDefault
  });
  return tableProps;
};

/** Table Tree - Should be used with useTableTree hook, (See grid documentation) all props go for useTable which return the gridProps (apart from className, disableAutoSizeColumns and isExternalFilter) */
var TreeTable = function TreeTable(tableProps) {
  return /*#__PURE__*/React__default.createElement("div", {
    className: 'Suc-tree-table'
  }, /*#__PURE__*/React__default.createElement(Grid, _extends({
    ExpandedRow: ExpandedRow
  }, tableProps)));
};
TreeTable.propTypes = {
  /** Show children by default */
  expandByDefault: PropTypes.bool,
  /** Array of accessors to search child rows */
  childrenSearchKeys: PropTypes.arrayOf(PropTypes.string)
};
TreeTable.defaultProps = {
  expandByDefault: true,
  childrenSearchKeys: []
};

export { TreeTable as default, useTreeTable };
//# sourceMappingURL=index.js.map
